==> haskell-geniplate-mirror-0.7.7-6-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-geniplate-mirror.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 geniplate-mirror
version:              0.7.7
visibility:           public
id:                   geniplate-mirror-0.7.7-DI3CPIz3KoIBfOxOp6VapP
key:                  geniplate-mirror-0.7.7-DI3CPIz3KoIBfOxOp6VapP
license:              BSD-3-Clause
copyright:            2014-2015 Lennart Augustsson
maintainer:
    Dan Rosén <dan.rosen@gu.se>, Liang-Ting Chen <liang.ting.chen.tw@gmail.com>

author:               Lennart Augustsson
stability:            experimental
homepage:             https://github.com/danr/geniplate
synopsis:             Use Template Haskell to generate Uniplate-like functions.
description:
    Use Template Haskell to generate Uniplate-like functions.

    This is a maintained mirror of the
    <http://hackage.haskell.org/package/geniplate geniplate> package,
    written by Lennart Augustsson.

category:             Generics
abi:                  ea4fa00343ca0f0598799f1feeaa82c9
exposed:              True
exposed-modules:      Data.Generics.Geniplate
import-dirs:          /usr/lib/ghc-8.10.4/site-local/geniplate-mirror-0.7.7
library-dirs:         /usr/lib/ghc-8.10.4/site-local/geniplate-mirror-0.7.7
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/x86_64-linux-ghc-8.10.4/geniplate-mirror-0.7.7
hs-libraries:         HSgeniplate-mirror-0.7.7-DI3CPIz3KoIBfOxOp6VapP
depends:              base-4.14.1.0 mtl-2.2.2 template-haskell-2.16.0.0
haddock-interfaces:
    /usr/share/doc/haskell-geniplate-mirror/html/geniplate-mirror.haddock

haddock-html:         /usr/share/doc/haskell-geniplate-mirror/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-geniplate-mirror-0.7.7-7-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-geniplate-mirror.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 geniplate-mirror
version:              0.7.7
visibility:           public
id:                   geniplate-mirror-0.7.7-8ymHeYerB3hH5xEFOTfhlg
key:                  geniplate-mirror-0.7.7-8ymHeYerB3hH5xEFOTfhlg
license:              BSD-3-Clause
copyright:            2014-2015 Lennart Augustsson
maintainer:
    Dan Rosén <dan.rosen@gu.se>, Liang-Ting Chen <liang.ting.chen.tw@gmail.com>

author:               Lennart Augustsson
stability:            experimental
homepage:             https://github.com/danr/geniplate
synopsis:             Use Template Haskell to generate Uniplate-like functions.
description:
    Use Template Haskell to generate Uniplate-like functions.

    This is a maintained mirror of the
    <http://hackage.haskell.org/package/geniplate geniplate> package,
    written by Lennart Augustsson.

category:             Generics
abi:                  5f629dc331a7d33cf31d9076e44ee30c
exposed:              True
exposed-modules:      Data.Generics.Geniplate
import-dirs:          /usr/lib/ghc-8.10.5/site-local/geniplate-mirror-0.7.7
library-dirs:         /usr/lib/ghc-8.10.5/site-local/geniplate-mirror-0.7.7
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/x86_64-linux-ghc-8.10.5/geniplate-mirror-0.7.7
hs-libraries:         HSgeniplate-mirror-0.7.7-8ymHeYerB3hH5xEFOTfhlg
depends:              base-4.14.2.0 mtl-2.2.2 template-haskell-2.16.0.0
haddock-interfaces:
    /usr/share/doc/haskell-geniplate-mirror/html/geniplate-mirror.haddock

haddock-html:         /usr/share/doc/haskell-geniplate-mirror/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
